/* Redundant header include test with C comments at top.  */
# /* And a null directive at the top.  */

#ifndef CPP_MIC_H
#define CPP_MIC_H

int a;

#endif

# /* And at the end, too!  */
/* And at the end too!  */
