-- C97113A.ADA

--                             Grant of Unlimited Rights
--
--     Under contracts F33600-87-D-0337, F33600-84-D-0280, MDA903-79-C-0687,
--     F08630-91-C-0015, and DCA100-97-D-0025, the U.S. Government obtained 
--     unlimited rights in the software and documentation contained herein.
--     Unlimited rights are defined in DFAR 252.227-7013(a)(19).  By making 
--     this public release, the Government intends to confer upon all 
--     recipients unlimited rights  equal to those held by the Government.  
--     These rights include rights to use, duplicate, release or disclose the 
--     released technical data and computer software in whole or in part, in 
--     any manner and for any purpose whatsoever, and to have or permit others 
--     to do so.
--
--                                    DISCLAIMER
--
--     ALL MATERIALS OR INFORMATION HEREIN RELEASED, MADE AVAILABLE OR
--     DISCLOSED ARE AS IS.  THE GOVERNMENT MAKES NO EXPRESS OR IMPLIED 
--     WARRANTY AS TO ANY MATTER WHATSOEVER, INCLUDING THE CONDITIONS OF THE
--     SOFTWARE, DOCUMENTATION OR OTHER INFORMATION RELEASED, MADE AVAILABLE 
--     OR DISCLOSED, OR THE OWNERSHIP, MERCHANTABILITY, OR FITNESS FOR A
--     PARTICULAR PURPOSE OF SAID MATERIAL.
--*
-- CHECK THAT ALL CONDITIONS, OPEN DELAY ALTERNATIVE EXPRESSIONS, AND
--   OPEN ENTRY FAMILY INDICES ARE EVALUATED (EVEN WHEN SOME (PERHAPS
--   ALL BUT ONE) OF THE ALTERNATIVES CAN BE RULED OUT WITHOUT
--   COMPLETING THE EVALUATIONS).

-- RM 5/06/82
-- SPS 11/21/82
-- WRG 7/9/86    ADDED DELAY EXPRESSIONS AND ENTRY FAMILY INDICES.

with Impdef;
WITH REPORT; USE REPORT;
PROCEDURE C97113A IS

     EXPR1_EVALUATED : BOOLEAN := FALSE;
     EXPR2_EVALUATED : BOOLEAN := FALSE;
     EXPR3_EVALUATED : BOOLEAN := FALSE;

     FUNCTION F1 RETURN BOOLEAN IS
     BEGIN
          EXPR1_EVALUATED := TRUE;
          RETURN TRUE;
     END F1;

     FUNCTION F2 (X : INTEGER) RETURN INTEGER IS
     BEGIN
          EXPR2_EVALUATED := TRUE;
          RETURN X;
     END F2;

     FUNCTION F3 (X : DURATION) RETURN DURATION IS
     BEGIN
          EXPR3_EVALUATED := TRUE;
          RETURN X;
     END F3;

BEGIN

     TEST ("C97113A", "CHECK THAT ALL CONDITIONS, OPEN DELAY " &
                      "ALTERNATIVE EXPRESSIONS, AND OPEN ENTRY " &
                      "FAMILY INDICES ARE EVALUATED");

     DECLARE

          TASK T IS
               ENTRY E1;
               ENTRY E2;
               ENTRY E3 (1..1);
          END T;

          TASK BODY T IS
          BEGIN
               --ENSURE THAT E1 HAS BEEN CALLED BEFORE PROCEEDING:
               WHILE E1'COUNT = 0 LOOP
                    DELAY 1.0 * Impdef.One_Second;
               END LOOP;

               SELECT
                    ACCEPT E1;
               OR
                    WHEN F1 =>
                         ACCEPT E2;
               OR
                    ACCEPT E3 ( F2(1) );
               OR
                    DELAY F3 ( 1.0 ) * Impdef.One_Second;
               END SELECT;
          END T;

     BEGIN

          T.E1;

     END;

     IF NOT EXPR1_EVALUATED THEN
          FAILED ("GUARD NOT EVALUATED");
     END IF;

     IF NOT EXPR2_EVALUATED THEN
          FAILED ("ENTRY FAMILY INDEX NOT EVALUATED");
     END IF;

     IF NOT EXPR3_EVALUATED THEN
          FAILED ("OPEN DELAY ALTERNATIVE EXPRESSION NOT EVALUATED");
     END IF;

     RESULT;

END C97113A;
